# Confirmation AEA AW2

An agent that purchases information from other agents as specified in its configuration. It acts as the confirmation AEA in Agent World 2.

## Description

This agent uses the `fetchai/confirmation_aw2` skill to purchase data from valid Agent World 2 participants.

## Links
